changeset 47704:8a5233d2f072

Setup ucs-unicode-to-mule-cjk and ucs-mule-cjk-to-unicode, not utf-8-subst-table and utf-8-subst-rev-table.
author Kenichi Handa <handa@m17n.org>
date Mon, 30 Sep 2002 06:36:23 +0000
parents 6d4430dfeafc
children 797c350a7f8c
files lisp/international/utf-8-subst.el
diffstat 1 files changed, 16 insertions(+), 15 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/international/utf-8-subst.el	Mon Sep 30 06:35:13 2002 +0000
+++ b/lisp/international/utf-8-subst.el	Mon Sep 30 06:36:23 2002 +0000
@@ -1,4 +1,4 @@
-;;; utf-8-subst.el --- translation of untranslatable utf-8 to CJK -*-coding: iso-2022-7bit;-*-
+;;; utf-8-subst.el --- translation of undecodable UTF-8/16 to CJK -*-coding: iso-2022-7bit;-*-
 
 ;; Copyright (C) 2001, 2002  Free Software Foundation, Inc.
 
@@ -24,22 +24,23 @@
 
 ;;; Commentary:
 
 ;; Defines hash table `utf-8-subst-table' which maps UTF-8 otherwise
 ;; `untranslatable' characters to characters in specific Emacs CJK
 ;; charsets.  The CJK charsets used are chinese-gb2312,
 ;; japanese-jisx0208 and korean-ksc5601.  Where their Unicodes
 ;; overlap, the priority used is J C K, guessing the likelihood of
 ;; fonts being available generally.  This can be altered by changing
 ;; the order in which the table is filled.  This should doubtless be
 ;; cusomizable somehow.
 
 ;;; Code:
 
 ;; korean-ksc5601
 (mapc
  (lambda (pair)
-   (puthash (car pair) (cadr pair) utf-8-subst-table)
-   (puthash (cadr pair) (car pair) utf-8-subst-rev-table))
+   (puthash (car pair) (cadr pair) ucs-unicode-to-mule-cjk)
+   (puthash (cadr pair) (car pair) ucs-mule-cjk-to-unicode))
  '((#x4E00 ?$(Cli(B)
    (#x4E01 ?$(CoK(B)
    (#x4E03 ?$(CvR(B)
@@ -7014,8 +7015,8 @@
 ;; chinese-gb2312
 (mapc
  (lambda (pair)
-   (puthash (car pair) (cadr pair) utf-8-subst-table)
-   (puthash (cadr pair) (car pair) utf-8-subst-rev-table))
+   (puthash (car pair) (cadr pair) ucs-unicode-to-mule-cjk)
+   (puthash (cadr pair) (car pair) ucs-mule-cjk-to-unicode))
  '((#x4E00 ?$AR;(B)
    (#x4E01 ?$A6!(B)
    (#x4E03 ?$AF_(B)
@@ -13784,8 +13785,8 @@
 ;; japanese-jisx0208
 (mapc
  (lambda (pair)
-   (puthash (car pair) (cadr pair) utf-8-subst-table)
-   (puthash (cadr pair) (car pair) utf-8-subst-rev-table))
+   (puthash (car pair) (cadr pair) ucs-unicode-to-mule-cjk)
+   (puthash (cadr pair) (car pair) ucs-mule-cjk-to-unicode))
  '((#x4E00 ?$B0l(B)
    (#x4E01 ?$BCz(B)
    (#x4E03 ?$B<7(B)
@@ -24,22 +24,23 @@
 ;;; Commentary:
 
-;; Defines hash table `utf-8-subst-table' which maps UTF-8 otherwise
-;; `untranslatable' characters to characters in specific Emacs CJK
-;; charsets.  The CJK charsets used are chinese-gb2312,
-;; japanese-jisx0208 and korean-ksc5601.  Where their Unicodes
-;; overlap, the priority used is J C K, guessing the likelihood of
-;; fonts being available generally.  This can be altered by changing
-;; the order in which the table is filled.  This should doubtless be
-;; cusomizable somehow.
+;; Defines hash table `ucs-unicode-to-mule-cjk' which maps UTF-8/16
+;; otherwise `undecodable' characters to characters in specific
+;; Emacs CJK charsets.  Defines also the hash table
+;; `ucs-mule-cjk-to-unicode' that does the reverse mapping.  The
+;; CJK charsets used are chinese-gb2312, japanese-jisx0208 and
+;; korean-ksc5601.  Where their Unicodes overlap, the priority used is
+;; J C K, guessing the likelihood of fonts being available generally.
+;; This can be altered by changing the order in which the table is
+;; filled.  This should doubtless be cusomizable somehow.
 
 ;;; Code: